pyLinky
=======
Get your consumption data from your Enedis account (www.enedis.fr) 

This library This is based on jeedom_linky, created by Outadoc (https://github.com/Asdepique777/jeedom_linky)

Installation
------------
    pip install pyLinky
    

Usage
-----
Print your current data

    pylink -u <USERNAME> -p <PASWORD>


Dev env
-------
    virtualenv -p /usr/bin/python3.5 env
    pip install -r requirements.txt